@@ -1,4 +1,4 @@
-module PragmaDocs where
+module PragmaDocs ({-# DEPRECATED "Do not use" #-} contains) where
 
 {-# DEPRECATED contains "Use `elem` instead." #-}
 contains :: (Eq a, Foldable f) => f a -> a -> Bool
